==> reql-cli-1.0.4.tgz: package/lib/repl.js <==
"use strict";

var _createClass = (function () { function defineProperties(target, props) { for (var key in props) { var prop = props[key]; prop.configurable = true; if (prop.value) prop.writable = true; } Object.defineProperties(target, props); } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _classCallCheck = function (instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } };

var clc = require("cli-color");
var Promise = require("bluebird");

var REPL = (function () {
  /**
   * @constructor
   * @param  {Client} client
   */

  function REPL(client) {
    _classCallCheck(this, REPL);

    this.client = client;
    this.history = [];
    this.preHistory = null;
    this.historyId = 0;
    this.commands = {
      dbs: this.client.getDbList.bind(this.client),
      tables: this.client.getTableList.bind(this.client),
      help: this.help.bind(this),
      db: function db(x) {
        return client.setDb(x);
      }
    };

    this.input = [];

    this.ignoredKeys = ["f1", "f2", "f3", "f4", "f5", "f6", "f7", "f8", "f9", "f10", "f11", "f12", "right", "left", "clear"];
  }

  _createClass(REPL, {
    prompt: {

      /**
       * Print the prompt for this REPL
       */

      value: function prompt() {
        process.stdout.write("\n" + clc.green("reql-cli") + clc.blue("> "));
      }
    },
    addToHistory: {

      /**
       * Add a command to the REPL history for quick retrieval
       * 
       * @param {String} entry
       * @return {void}
       */

      value: function addToHistory(entry) {
        this.historyId = 0;
        if (this.history.indexOf(entry) === -1) {
          this.history = [entry].concat(this.history.slice(0, 8));
        }
      }
    },
    clearInput: {

      /**
       * Clear the current input of the REPL
       * 
       * @return {void}
       */

      value: function clearInput() {
        this.input.forEach(function (c) {
          process.stdout.write("\b \b", "utf8");
        });
        this.input = [];
      }
    },
    setInput: {

      /**
       * Set the current input to the given value
       * 
       * @param {String} val
       * @return {void}
       */

      value: function setInput(val) {
        if (!val) {
          return;
        }
        process.stdout.write(val);
        this.input = val.split("");
      }
    },
    start: {

      /**
       * Start the REPL listening in on Stdin keypresses
       * 
       * @return {void}
       */

      value: function start() {
        var that = this;
        var keypress = require("keypress");

        process.stdout.write(clc.green("- RethinkDB Command Line Interface v1.0.0\n- Courtesy of Workshape.io"));
        that.prompt();
        process.stdin.setEncoding("utf8");

        keypress(process.stdin);

        process.stdin.on("keypress", function (ch, key) {
          if (key && that.ignoredKeys.indexOf(key.name) > -1) {
            return;
          } else if (key && !key.ctrl && key.name === "up") {
            if (that.history.length > 0 && that.historyId < that.history.length) {
              if (that.historyId === 0) {
                that.preHistory = that.input.join("");
              }
              that.clearInput();
              that.setInput(that.history[that.historyId++]);
            }
          } else if (key && !key.ctrl && key.name === "down") {
            if (that.historyId > 0) {
              that.clearInput();
              that.setInput(that.history[that.historyId--]);
            } else if (that.preHistory) {
              that.clearInput();
              that.setInput(that.preHistory);
              that.preHistory = null;
            }
          } else if (key && !key.ctrl && key.name === "return") {
            var chunk = that.input.join("");
            that.input = [];
            if (chunk) {
              process.stdout.write("\n", "utf8");
              that.handle(chunk.trim());
            } else {
              that.prompt();
            }
          } else if (key && key.ctrl && key.name === "c") {
            console.log(clc.yellow("\n[.] Closing reql-cli..."));
            process.exit(0);
          } else if (key && !key.ctrl && (key.name === "delete" || key.name === "backspace")) {
            if (that.input.length > 0) {
              process.stdout.write("\b \b", "utf8");
              that.input.pop();
            }
          } else {
            process.stdout.write(ch, "utf8");
            that.input.push(ch);
          }
        });

        process.stdin.setRawMode(true);
      }
    },
    handle: {

      /**
       * Handle a command given by the user
       * 
       * @param  {String} input
       * @return {void}
       */

      value: function handle(input) {
        var that = this,
            promise;
        var args = input.split(" ");
        if (that.commands[args[0]]) {
          promise = that.commands[args[0]](args[1]);
        } else {
          promise = that.client.query(input);
        }

        promise.then(function () {
          that.addToHistory(input);
        })["catch"](function (e) {
          console.log(clc.red(e));
          that.help();
        })["finally"](function () {
          that.prompt();
        });
      }
    },
    help: {
      value: function help() {
        process.stdout.write("\n", "utf8");
        console.log(clc.yellow("[-] Available commands:\n        - dbs - print available databases\n        - db {db} - change current db to {db}\n        - tables - print available tables in current db\n        - r... - any rethink valid query, omitting run()\n\n        - press ctrl + c to quit"));
        return Promise.resolve();
      }
    }
  });

  return REPL;
})();

module.exports = REPL;

==> reql-cli-1.0.6.tgz: package/lib/repl.js <==
"use strict";

var _createClass = (function () { function defineProperties(target, props) { for (var key in props) { var prop = props[key]; prop.configurable = true; if (prop.value) prop.writable = true; } Object.defineProperties(target, props); } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _classCallCheck = function (instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } };

var clc = require("cli-color");
var Promise = require("bluebird");

var REPL = (function () {
  /**
   * @constructor
   * @param  {Client} client
   */

  function REPL(client) {
    _classCallCheck(this, REPL);

    this.client = client;
    this.history = [];
    this.preHistory = null;
    this.historyId = 0;
    this.commands = {
      dbs: this.client.getDbList.bind(this.client),
      tables: this.client.getTableList.bind(this.client),
      help: this.help.bind(this),
      db: function db(x) {
        return client.setDb(x);
      }
    };

    this.input = [];
    this.cursor = 0;

    this.ignoredKeys = ["f1", "f2", "f3", "f4", "f5", "f6", "f7", "f8", "f9", "f10", "f11", "f12", "clear"];
  }

  _createClass(REPL, {
    prompt: {

      /**
       * Print the prompt for this REPL
       */

      value: function prompt() {
        process.stdout.write("\n" + clc.green("reql-cli") + clc.blue("> "));
      }
    },
    addToHistory: {

      /**
       * Add a command to the REPL history for quick retrieval
       * 
       * @param {String} entry
       * @return {void}
       */

      value: function addToHistory(entry) {
        this.historyId = 0;
        if (this.history.indexOf(entry) === -1) {
          this.history = [entry].concat(this.history.slice(0, 8));
        }
      }
    },
    clearInput: {

      /**
       * Clear the current input of the REPL
       * 
       * @return {void}
       */

      value: function clearInput() {
        this.input.forEach(function (c) {
          process.stdout.write("\b \b", "utf8");
        });
        this.input = [];
      }
    },
    setInput: {

      /**
       * Set the current input to the given value
       * 
       * @param {String} val
       * @return {void}
       */

      value: function setInput(val) {
        if (!val) {
          return;
        }
        process.stdout.write(val);
        this.input = val.split("");
      }
    },
    start: {

      /**
       * Start the REPL listening in on Stdin keypresses
       * 
       * @return {void}
       */

      value: function start() {
        var that = this;
        var keypress = require("keypress");

        process.stdout.write(clc.green("- RethinkDB Command Line Interface v1.0.0\n- Courtesy of Workshape.io"));
        that.prompt();
        process.stdin.setEncoding("utf8");

        keypress(process.stdin);

        process.stdin.on("keypress", function (ch, key) {
          if (key && that.ignoredKeys.indexOf(key.name) > -1) {
            return;
          } else if (key && !key.ctrl && key.name === "up") {
            if (that.history.length > 0 && that.historyId < that.history.length) {
              if (that.historyId === 0) {
                that.preHistory = that.input.join("");
              }
              that.clearInput();
              that.setInput(that.history[that.historyId++]);
            }
          } else if (key && !key.ctrl && key.name === "down") {
            if (that.historyId > 0) {
              that.clearInput();
              that.setInput(that.history[that.historyId--]);
            } else if (that.preHistory) {
              that.clearInput();
              that.setInput(that.preHistory);
              that.preHistory = null;
            }
          } else if (key && !key.ctrl && key.name === "return") {
            var chunk = that.input.join("");
            that.input = [];
            if (chunk) {
              process.stdout.write("\n", "utf8");
              that.handle(chunk.trim());
            } else {
              that.prompt();
            }
          } else if (key && key.ctrl && key.name === "c") {
            console.log(clc.yellow("\n[.] Closing reql-cli..."));
            process.exit(0);
          } else if (key && !key.ctrl && (key.name === "delete" || key.name === "backspace")) {
            if (that.input.length > 0) {
              process.stdout.write("\b \b", "utf8");
              that.input.pop();
              if (that.cursor > 0) {
                process.stdout.write("\b", "utf8");
                that.cursor--;
              }
            }
          } else if (key && !key.ctrl && key.name === "left") {
            if (that.input.length > 0 && that.cursor < that.input.length) {
              process.stdout.write("\b", "utf8");
              that.cursor++;
            }
          } else if (key && !key.ctrl && key.name === "right") {
            if (that.input.length > 0 && that.cursor > 0) {

              process.stdout.write(that.input[that.input.length - that.cursor], "utf8");
              --that.cursor;
            }
          } else {
            process.stdout.write(ch, "utf8");
            if (that.cursor !== 0) {
              that.input[that.input.length - that.cursor] = ch;
              --that.cursor;
            } else {
              that.input.push(ch);
            }
          }
        });

        process.stdin.setRawMode(true);
      }
    },
    handle: {

      /**
       * Handle a command given by the user
       * 
       * @param  {String} input
       * @return {void}
       */

      value: function handle(input) {
        var that = this,
            promise;
        var args = input.split(" ");
        if (that.commands[args[0]]) {
          promise = that.commands[args[0]](args[1]);
        } else {
          promise = that.client.query(input);
        }

        promise.then(function () {
          that.addToHistory(input);
        })["catch"](function (e) {
          console.log(clc.red(e));
          that.help();
        })["finally"](function () {
          that.prompt();
        });
      }
    },
    help: {
      value: function help() {
        process.stdout.write("\n", "utf8");
        console.log(clc.yellow("[-] Available commands:\n        - dbs - print available databases\n        - db {db} - change current db to {db}\n        - tables - print available tables in current db\n        - r... - any rethink valid query, omitting run()\n\n        - press ctrl + c to quit"));
        return Promise.resolve();
      }
    }
  });

  return REPL;
})();

module.exports = REPL;
